/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQTableToolBar.h"

/**
 * \brief Sets up the GUI.
 *
 * \param parent Pointer to the parent QWidget.
 */
UCQTableToolBar::UCQTableToolBar ( QWidget* parent ) :
    QToolBar ( parent )
{
    QIcon zoomInIcon        ( ":icons/view-fullscreen.svg"      );
    QIcon zoomOutIcon       ( ":icons/view-fullscreen-exit.svg" );
    QIcon searchIcon        ( ":icons/system-search.svg"        );
    QIcon addBlockIcon      ( ":icons/edit-blocks.svg"          );
    QIcon clearTableIcon    ( ":icons/edit-clear.svg"           );
    QIcon cutSelectionIcon  ( ":icons/edit-cut.svg"             );
    QIcon cropSelectionIcon ( ":icons/edit-crop.svg"            );

    zoomInAction_        = new QAction ( zoomInIcon,        "", this );
    zoomOutAction_       = new QAction ( zoomOutIcon,       "", this );
    searchAction_        = new QAction ( searchIcon,        "", this );
    addBlockAction_      = new QAction ( addBlockIcon,      "", this );
    clearAction_         = new QAction ( clearTableIcon,    "", this );
    cutSelectionAction_  = new QAction ( cutSelectionIcon,  "", this );
    cropSelectionAction_ = new QAction ( cropSelectionIcon, "", this );

    zoomInAction_->setToolTip        ( tr ( "Zoom in" ) );
    zoomOutAction_->setToolTip       ( tr ( "Zoom out" ) );
    searchAction_->setToolTip        ( tr ( "Find Letter" ) );
    addBlockAction_->setToolTip      ( tr ( "New Block" ) );
    clearAction_->setToolTip         ( tr ( "Clear Table" ) );
    cutSelectionAction_->setToolTip  ( tr ( "Cut selected Items" ) );
    cropSelectionAction_->setToolTip ( tr ( "Reduce Table on selected Items" ) );

    addAction ( zoomInAction_  );
    addAction ( zoomOutAction_ );
    addSeparator ();
    addAction ( clearAction_         );
    addAction ( cutSelectionAction_  );
    addAction ( cropSelectionAction_ );
    addSeparator ();
    addAction ( searchAction_   );
    addSeparator ();
    addAction ( addBlockAction_ );

    connect ( zoomInAction_, SIGNAL ( triggered () ),
              this,          SIGNAL ( zoomInPressed () ) );

    connect ( zoomOutAction_, SIGNAL ( triggered () ),
              this,           SIGNAL ( zoomOutPressed () ) );

    connect ( searchAction_, SIGNAL ( triggered () ),
              this,          SIGNAL ( searchPressed () ) );

    connect ( addBlockAction_, SIGNAL ( triggered () ),
              this,            SIGNAL ( addBlockPressed () ) );

    connect ( clearAction_, SIGNAL ( triggered () ),
              this,         SIGNAL ( clearPressed () ) );

    connect ( cutSelectionAction_, SIGNAL ( triggered () ),
              this,                SIGNAL ( cutSelectionPressed () ) );

    connect ( cropSelectionAction_, SIGNAL ( triggered () ),
              this,                 SIGNAL ( cropSelectionPressed () ) );
}

/**
 * \brief En-/disable all actions except for add block.
 *
 * \param enable True sets the actions enabled, false disabled.
 *
 * \see MainWindow::updateStates()
 */
void UCQTableToolBar::enableActions ( bool enable )
{
    zoomOutAction_->setEnabled       ( enable );
    zoomInAction_->setEnabled        ( enable );
    searchAction_->setEnabled        ( enable );
    clearAction_->setEnabled         ( enable );
    cutSelectionAction_->setEnabled  ( enable );
    cropSelectionAction_->setEnabled ( enable );
}

/**
 * \brief En-/disable the add block action.
 *
 * \param enable True sets the action enabled, false disabled.
 */
void UCQTableToolBar::enableAddBlockAction ( bool enable )
{
    addBlockAction_->setEnabled ( enable );
}
